==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/PublicIPAddressSkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.PublicIPAddressSkuArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.PublicIPAddressSkuName
import com.pulumi.azurenative.network.kotlin.enums.PublicIPAddressSkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * SKU of a public IP address.
 * @property name Name of a public IP address SKU.
 * @property tier Tier of a public IP address SKU.
 */
public data class PublicIPAddressSkuArgs(
    public val name: Output<Either<String, PublicIPAddressSkuName>>? = null,
    public val tier: Output<Either<String, PublicIPAddressSkuTier>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.PublicIPAddressSkuArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.PublicIPAddressSkuArgs =
        com.pulumi.azurenative.network.inputs.PublicIPAddressSkuArgs.builder()
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [PublicIPAddressSkuArgs].
 */
@PulumiTagMarker
public class PublicIPAddressSkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, PublicIPAddressSkuName>>? = null

    private var tier: Output<Either<String, PublicIPAddressSkuTier>>? = null

    /**
     * @param value Name of a public IP address SKU.
     */
    @JvmName("posxncocqohhirko")
    public suspend fun name(`value`: Output<Either<String, PublicIPAddressSkuName>>) {
        this.name = value
    }

    /**
     * @param value Tier of a public IP address SKU.
     */
    @JvmName("ncjxgfgltijajegh")
    public suspend fun tier(`value`: Output<Either<String, PublicIPAddressSkuTier>>) {
        this.tier = value
    }

    /**
     * @param value Name of a public IP address SKU.
     */
    @JvmName("rmpsbyyvwqofewuv")
    public suspend fun name(`value`: Either<String, PublicIPAddressSkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a public IP address SKU.
     */
    @JvmName("wovojwjxwapacrfb")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PublicIPAddressSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a public IP address SKU.
     */
    @JvmName("kbwrbwhssammlhxj")
    public fun name(`value`: PublicIPAddressSkuName) {
        val toBeMapped = Either.ofRight<String, PublicIPAddressSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Tier of a public IP address SKU.
     */
    @JvmName("knrjgtoiuearikkl")
    public suspend fun tier(`value`: Either<String, PublicIPAddressSkuTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a public IP address SKU.
     */
    @JvmName("rbjteovmnnccejve")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PublicIPAddressSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a public IP address SKU.
     */
    @JvmName("pypsufvgpwdqkfug")
    public fun tier(`value`: PublicIPAddressSkuTier) {
        val toBeMapped = Either.ofRight<String, PublicIPAddressSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): PublicIPAddressSkuArgs = PublicIPAddressSkuArgs(
        name = name,
        tier = tier,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/PublicIPAddressSkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.PublicIPAddressSkuArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.PublicIPAddressSkuName
import com.pulumi.azurenative.network.kotlin.enums.PublicIPAddressSkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * SKU of a public IP address.
 * @property name Name of a public IP address SKU.
 * @property tier Tier of a public IP address SKU.
 */
public data class PublicIPAddressSkuArgs(
    public val name: Output<Either<String, PublicIPAddressSkuName>>? = null,
    public val tier: Output<Either<String, PublicIPAddressSkuTier>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.PublicIPAddressSkuArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.PublicIPAddressSkuArgs =
        com.pulumi.azurenative.network.inputs.PublicIPAddressSkuArgs.builder()
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [PublicIPAddressSkuArgs].
 */
@PulumiTagMarker
public class PublicIPAddressSkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, PublicIPAddressSkuName>>? = null

    private var tier: Output<Either<String, PublicIPAddressSkuTier>>? = null

    /**
     * @param value Name of a public IP address SKU.
     */
    @JvmName("gpxxhpwufkatmkpk")
    public suspend fun name(`value`: Output<Either<String, PublicIPAddressSkuName>>) {
        this.name = value
    }

    /**
     * @param value Tier of a public IP address SKU.
     */
    @JvmName("odisqdmqbqkmbjor")
    public suspend fun tier(`value`: Output<Either<String, PublicIPAddressSkuTier>>) {
        this.tier = value
    }

    /**
     * @param value Name of a public IP address SKU.
     */
    @JvmName("baolsdkljvovaeax")
    public suspend fun name(`value`: Either<String, PublicIPAddressSkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a public IP address SKU.
     */
    @JvmName("ouwnhfgcmfsnmgih")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PublicIPAddressSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a public IP address SKU.
     */
    @JvmName("sqldewikobxuhigg")
    public fun name(`value`: PublicIPAddressSkuName) {
        val toBeMapped = Either.ofRight<String, PublicIPAddressSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Tier of a public IP address SKU.
     */
    @JvmName("yhiyniqlhmhxqhji")
    public suspend fun tier(`value`: Either<String, PublicIPAddressSkuTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a public IP address SKU.
     */
    @JvmName("euxsdmbqljmpiqvu")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PublicIPAddressSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a public IP address SKU.
     */
    @JvmName("radpbbjrepkubrlq")
    public fun tier(`value`: PublicIPAddressSkuTier) {
        val toBeMapped = Either.ofRight<String, PublicIPAddressSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): PublicIPAddressSkuArgs = PublicIPAddressSkuArgs(
        name = name,
        tier = tier,
    )
}
